@@ -89,7 +89,7 @@ QString KCheckComboBox::Private::squeeze(const QString &text)
     const int minLB = qMax(0, -fm.minLeftBearing());
     const int minRB = qMax(0, -fm.minRightBearing());
     const int lineEditWidth = q->lineEdit()->width() - 4 - minLB - minRB;
-    const int textWidth = fm.width(text);
+    const int textWidth = fm.boundingRect(text).width();
     if (textWidth > lineEditWidth) {
         return fm.elidedText(text, Qt::ElideMiddle, lineEditWidth);
     }
@@ -149,12 +149,17 @@ KCheckComboBox::KCheckComboBox(QWidget *parent)
         d->updateCheckedItems(topLeft, bottomRight);
     });
 
+
     // read-only contents
     setEditable(true);
+
     lineEdit()->setAlignment(Qt::AlignLeft);
-    // The cast is a workaround for the fact that QLineEdit::setReadOnly isn't virtual.
-    // KLineEdit copes with this case since kdelibs-4.6 though.
-    qobject_cast<KLineEdit *>(lineEdit())->setReadOnly(true);
+    connect(lineEdit(), &QLineEdit::textChanged, this, [this](const QString &text) {
+        if (text.isEmpty()) {
+            //Clear checked items
+            setCheckedItems(QStringList());
+        }
+    });
     setInsertPolicy(KComboBox::NoInsert);
 
     view()->installEventFilter(this);
