@@ -1,9 +1,10 @@
 /*
-  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+  under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -15,8 +16,8 @@
   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
-#ifndef ADDRESSEELINEEDITSTATIC_H
-#define ADDRESSEELINEEDITSTATIC_H
+#ifndef ADDRESSEELINEEDITMANAGER_H
+#define ADDRESSEELINEEDITMANAGER_H
 
 #include <QMap>
 #include <AkonadiCore/Collection>
@@ -133,4 +134,4 @@ private:
     QNetworkConfigurationManager *mNetworkConfigMgr = nullptr;
 };
 }
-#endif // ADDRESSEELINEEDITSTATIC_H
+#endif // ADDRESSEELINEEDITMANAGER_H
